@@ -18,5 +18,5 @@ def get_bjd_df():
     # print(os.path.abspath(__file__))
 
     data_path = os.path.abspath(__file__).replace("test.py", "data")
-    with open(f"{data_path}/bjd.pkl", "rb") as f:
+    with open(f"{data_path}/bjd_20220401.pkl", "rb") as f:
         return pickle.load(f)
